/* :: ekgedit project
   :: $Id: otak2ekg.c,v 1.1.1.1 2003/02/23 12:00:47 loth Exp $
   :: license: gnu gpl v 2
      copyright (c) 2002 - 2003 
   :: grzegorz moskal, <g.moskal@opengroup.org>			*/

#define OTAK2EKG_C
#include "otak2ekg.h"

static char *names[] = { "name", "last", "nick", "display", "phone", "groups", "uin" };
static char *base, *userlist, *backup;

static int find_id(char *name)
{
	int i = Name;
	for (; i <= Uin; i++)
		if (strcmp(name, names[i]) == 0)
			break;
	return i;
}

static void parse_persons(FILE *in, FILE *out)
{
	char *values[Uin+1];
	char *line, *name, *value;
	int i;
	for (i = Name; i <= Uin; i++)
		values[i] = "";
	for (;;) {
		line = read_line(in);
		if (line == NULL || *line == '[')
			break;
		name = strtok(line, "=");
		value = strtok(NULL, "\0");
		values[find_id(name)] = strdup(value);
		xfree(line);
	}

	for (i = Name; i <= Uin; i++) {
		fprintf(out, "%s%s", values[i], (i != Uin) ? ";" : "\n");
		if (values[i][0])
			xfree(values[i]);
	}

	if (line) {
		xfree(line);
		parse_persons(in, out);
	}
	
}

void make_userlist(FILE *in, FILE *out)
{
	xfree(read_line(in));
	parse_persons(in, out);
	fclose(in);
	fclose(out);
}

int main(int argc, char **argv)
{
	if (parse_cmdline(argc, argv) == 0)
		return 0;
		
	if (base == NULL)
		base = strdglue(getenv("HOME"), ".otak/ekglist");
		
	if (userlist == NULL) {
		userlist = strdglue(getenv("HOME"), ".gg/userlist");
		backup = strdglue(getenv("HOME"), ".gg/.otak2ekg-userlist-backup");
	}

	if (backup)
		xcp(userlist, backup);
		
	make_userlist(xfopen(base, "r"), xfopen(userlist, "w+"));
	
	return 0;
}

static int parse_cmdline(int argc, char **argv)
{
	int i = 1;
	char *opt;
	for (; i < argc; i++)  {
		opt = argv[i];
		if (strcmp(opt, "--in") == 0) {
			if (i+1 < argc) 
				base = strdup(argv[++i]);
			else {
				printf("option --in needs <filname>\n");
				return 0;
			}
		} else if (strcmp(opt, "--out") == 0) {
			if (i+1 < argc) 
				userlist = strdup(argv[++i]);
			else {
				printf("option --out needs <filname>\n");
				return 0;
			}
		} else if (strcmp(opt, "--help") == 0) {
			printf("usage:  ekg2otak [options]\n\n"
				"--in   <filename>\tread otak database from this file\n"
				"--out  <filename>\twrite ekg userlist into this file\n"
				"--help           \tshow this info message\n\n");
			return 0;
		} else {
			printf("option \"%s\" !recognized ;(.\n", opt);
			printf("try: %s --help\n", argv[0]);
			return 0;
		}
	}
	return 1;
	
}

